# allib

[![Build Status](https://travis-ci.org/anlutro/allib.py.svg?branch=master)](https://travis-ci.org/anlutro/allib.py)
[![Latest version on PyPI](https://img.shields.io/pypi/v/allib.svg?maxAge=2592000)](https://pypi.python.org/pypi/allib)
[![Licence](https://img.shields.io/badge/license-MIT-blue.svg)](https://opensource.org/licenses/MIT)
